/* 
 * Copyright (C) 2009 Registro.br. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 1. Redistribution of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY REGISTRO.BR ``AS IS AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIE OF FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL REGISTRO.BR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
/* $Id: IpNetworkCreateRsp.H 963 2008-12-11 15:31:29Z rafael $ */
/** @file  IpNetworkCreateRsp.H
 *  @brief EPP IpNetworkCreateRsp Class
 */

#ifndef __IPNETWORKCREATERSP_H__
#define __IPNETWORKCREATERSP_H__

#include <string>

#include "libepp_nicbr.H"

#include "Response.H"

using std::string;

LIBEPP_NICBR_NS_BEGIN

/// EPP IpNetworkCreateRsp Class
class IpNetworkCreateRsp : public Response
{
public:
  /// Default constructor
  IpNetworkCreateRsp(bool reset = true) : Response(false)
  {
    if (reset) {
      this->reset();
    }
  }

  /// Sets ip range
  /**
     @param ipRange  ip range
  */
  void set_ipRange(const IpRange &ipRange)
  {
    _ipRange = ipRange;
  }

  /// Returns ip range
  /**
     @return ip range
  */
  IpRange get_ipRange() const
  {
    return _ipRange;
  }

  /// Sets repository object ID
  /**
     @param roid   contains the server-unique id for the created IP network
  */
  void set_roid(const string &roid)
  {
    _roid = roid;
  }

  /// Returns repository object ID
  /**
     @return server-unique id for the created IP network
  */
  string get_roid() const
  {
    return _roid;
  }

  /// Sets creation date
  /**
     @param crDate   object creation date
   */
  void set_crDate(string crDate) { _crDate = crDate; }

  /// Returns creation date
  /**
     @return creation date
   */
  string get_crDate() { return _crDate; }

  /// Sets expiration date
  /**
     @param exDate   expiration date
   */
  void set_exDate(string exDate) { _exDate = exDate; }

  /// Returns expiration date
  /**
     @return expiration date
   */
  string get_exDate() { return _exDate; }

  void reset()
  {
    Response::reset();
    _ipRange.reset();
    _roid = "";
    _crDate = "";
    _exDate = "";
  }

private:
  /// ip range
  IpRange _ipRange;

  /// server-unique id for the created IP network
  string _roid;

  /// date and time of object creation
  string _crDate;

  /// date and time identifying the end of the domain object's
  /// registration period
  string _exDate;
};

LIBEPP_NICBR_NS_END
#endif // __IPNETWORKCREATERSP_H__
